default source encoding is now utf-8
diff --git a/Tools/scripts/findnocoding.py b/Tools/scripts/findnocoding.py
index a049c0f..84dc3e0 100755
--- a/Tools/scripts/findnocoding.py
+++ b/Tools/scripts/findnocoding.py
@@ -62,11 +62,11 @@
         infile.close()
         return False
 
     # check the whole file for non-ASCII characters
     rest = infile.read()
     infile.close()
 
-    if has_correct_encoding(line1+line2+rest, "ascii"):
+    if has_correct_encoding(line1+line2+rest, "utf-8"):
         return False
 
     return True
@@ -62,11 +62,11 @@
         return False
 
-    # check the whole file for non-ASCII characters
+    # check the whole file for non utf-8 characters
     rest = infile.read()
     infile.close()